#!/usr/bin/env python
import argparse
import json
import sys

import yaml


def main():
    parser = argparse.ArgumentParser()
    parser.add_argument('file', nargs='?', default=None,
                        help='File to translate. Defaults to stdin.')
    parser.add_argument('-c', '--compressed', action='store_true',
                        help='Print JSON with no superfluous whitespace.')
    parser.add_argument('-p', '--pretty', action='store_true',
                        help='Enables pretty-printing of JSON')
    args = parser.parse_args()

    indent = 2 if args.pretty else None
    separators = (',', ':') if not args.pretty and args.compressed else None

    if args.file is not None:
        with open(args.file, 'r') as stream:
            data = yaml.safe_load(stream)
    else:
        if sys.stdin.isatty():
            sys.stderr.write('Warning: reading interactively from stdin.\n')
        data = yaml.safe_load(sys.stdin)

    sys.stdout.write(json.dumps(data, indent=indent, separators=separators))

if __name__ == '__main__':
    main()



#!/usr/bin/env python
try:
    from setuptools import setup, find_packages
except ImportError:
    from distutils.core import setup, find_packages

with open('README.md', 'r') as fh:
    long_description = fh.read()

setup(
    name='y2j',
    version='0.0.3',
    author='Neal Ormsbee',
    author_email='neal.ormsbee@gmail.com',
    description='A CLI tool for converting YAML to JSON.',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/SheepGotoHeaven/y2j',
    install_requires=['pyyaml'],
    packages=find_packages(),
    license='MIT',
    zip_safe=True,
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    entry_points={
        'console_scripts': [
            'y2j = y2j.__main__:main'
        ]
    }
)
